/* =====  Slider ===== */

.slider
{
    width:980px;
    height:450px;
    position:relative;
    overflow:hidden;
    margin:0px auto 30px;
    padding:0;
    background-color:white;
    -moz-border-radius: 5px;
    -webkit-border-radius:5px;
    border-radius:5px;
    font-size:80%;
}

.slider a.autoFlowPlayer
{
    width:600px;
    height:450px;
    position:relative;
    margin:0;
}

.slider a.autoFlowPlayer img.splash
{
    width:600px;
    height:450px;
}

.slider .pastEventDateUntil, .slider .futureEventDateUntil
{
    margin-right: 10px;
}

.slider-item
{
    width:980px;
    height:450px;
    position:absolute;
    top:0;
    left:0;
    background-color:white;
    -moz-border-radius: 5px;
    -webkit-border-radius:5px;
    border-radius:5px;
}

.slider-item-subtitle
{
    color: #3C3C3C !important;
    font-size: 13px;
    font-weight: bold;
}

.slider-item-subtitle.nolink:hover
{
    text-decoration:none;
}

.WorkAuthors a
{
    color:#8c8c8c !important;
}
.slider-item-image
{
    max-width:600px;
    max-height:450px;
    height:auto;
    width:auto;
    position:absolute;
    margin-right:20px;
    top:0;
    left:0;
}

.imageLinkOnSlider
{
    text-align:center;
    height:450px;
    width: 600px;
    position: absolute;
}

.slider-buttons
{
    position:absolute;
    right:20px;
    bottom:20px;
    left:620px;
    border-top: 1px solid #E0E0E0;
    padding-top:20px;
    text-align:right;
}

.slider-type-buttons
{
    position:absolute;
    right:20px;
    bottom:80px;
    left:620px;
    padding-top:0px;
    text-align:left;
}

.slider-button-next, .slider-button-prev
{
    display:inline;
    cursor:pointer;
}

input.slider-button-next[type="button"],  input.slider-button-prev[type="button"], input.slider-button[type="button"]
{
    color: #8c8c8c;
    text-decoration: none;
    background-color:transparent;
    padding:3px;
    border:none;
}

input.slider-button-prev:hover[type="button"],  input.slider-button-next:hover[type="button"], input.slider-button:hover[type="button"]
{
    color:white;
    background-color:#3c3c3c;
}

.slider-button-active
{
    color:white !important;
    background-color:#3c3c3c !important;
}


.slider-item-info
{
    padding:20px 0 20px 0;
    position:absolute;
    top:0;
    right:20px;
    left:620px;
}

a.slider-item-title
{
    border-bottom: 1px solid #E0E0E0;
    padding-bottom:20px;
    margin-bottom:20px;
    color: #3c3c3c;
    font-size:17px;
    font-weight:bold;
    display:block;
}

a.slider-item-title:hover
{
    text-decoration:none;
}

.slider-item-image-link
{
    left: 280px;
    position: absolute;
    top: 200px;
}